@@ -466,10 +466,19 @@ def generate_ctest(checks):
     filename = clazy_source_path() + 'ClazyTests.generated.cmake'
 
     contents = """# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n
+if ($ENV{CI_JOB_NAME_SLUG} MATCHES "qt5")
+    set(TEST_VERSION_OPTION "--qt-versions=5")
+elseif($ENV{CI_JOB_NAME_SLUG} MATCHES "qt6")
+    set(TEST_VERSION_OPTION "--qt-versions=6")
+endif()
+
 macro(add_clazy_test name)
-  add_test(NAME ${name} COMMAND python3 run_tests.py ${name} --verbose WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}/tests/)
+  add_test(NAME ${name} COMMAND python3 run_tests.py ${name} --verbose ${TEST_VERSION_OPTION} WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}/tests/)
+  if (CLANG_EXECUTABLE_PATH)
+    set(CLANG_CXX_TEST "CLANGXX=${CLANG_EXECUTABLE_PATH};")
+  endif()
   set_property(TEST ${name} PROPERTY
-    ENVIRONMENT "CLAZYPLUGIN_CXX=$<TARGET_FILE:ClazyPlugin>;CLAZYSTANDALONE_CXX=$<TARGET_FILE:clazy-standalone>;$<$<BOOL:${HAS_STD_FILESYSTEM}>:CLAZY_HAS_FILESYSTEM=>"
+    ENVIRONMENT "${CLANG_CXX_TEST}CLAZYPLUGIN_CXX=$<TARGET_FILE:ClazyPlugin>;CLAZYSTANDALONE_CXX=$<TARGET_FILE:clazy-standalone>;$<$<BOOL:${HAS_STD_FILESYSTEM}>:CLAZY_HAS_FILESYSTEM=>"
   )
 endmacro()\n
 """
