@@ -80,8 +80,12 @@ std::string clazy::getMostNeededQualifiedName(const SourceManager &sourceManager
             if (sourceManager.isBeforeInSLocAddrSpace(usageLoc, u->getBeginLoc())) {
                 continue;
             }
+#if LLVM_VERSION_MAJOR >= 19
+            visibleContexts.push_back(ns->getFirstDecl());
+#else
 
             visibleContexts.push_back(ns->getOriginalNamespace());
+#endif
         }
     }
 
@@ -148,7 +152,7 @@ bool clazy::canTakeAddressOf(CXXMethodDecl *method, DeclContext *context, bool &
         TypeSourceInfo *si = fr->getFriendType();
         if (si) {
             const Type *t = si->getType().getTypePtrOrNull();
-            CXXRecordDecl *friendClass = t ? t->getAsCXXRecordDecl() : nullptr;
+            const CXXRecordDecl *friendClass = t ? t->getAsCXXRecordDecl() : nullptr;
             if (friendClass == contextRecord) {
                 return true;
             }
