@@ -11,13 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class SourceLocation;
-class Stmt;
-} // namespace clang
-
 /**
  * See README-empty-qstringliteral.md for more info.
  */
