@@ -9,17 +9,14 @@
 
 #include "checkbase.h"
 
+#include <clang/Basic/Diagnostic.h>
 #include <string>
 #include <vector>
 
-class ClazyContext;
-
 namespace clang
 {
-class Stmt;
 class CallExpr;
 class CXXMemberCallExpr;
-class FixItHint;
 }
 
 /**
