@@ -11,12 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Decl;
-} // namespace clang
-
 /**
  * See README-child-event-qobject-cast for more info.
  */
