@@ -11,13 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Decl;
-class Stmt;
-} // namespace clang
-
 /**
  * See README-const-signal-or-slot.md for more info.
  */
