@@ -11,12 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Stmt;
-} // namespace clang
-
 /**
  * See README-post-event for more info.
  */
@@ -25,8 +19,6 @@ class PostEvent : public CheckBase
 public:
     explicit PostEvent(const std::string &name, ClazyContext *context);
     void VisitStmt(clang::Stmt *stmt) override;
-
-private:
 };
 
 #endif
