@@ -11,12 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Stmt;
-} // namespace clang
-
 /**
  * - QDeleteAll:
  *   - Finds places where you call qDeleteAll(set/map/hash.values()/keys())
