@@ -14,13 +14,8 @@
 
 #include <string>
 
-class ClazyContext;
-
 namespace clang
 {
-class ForStmt;
-class ValueDecl;
-class Stmt;
 class CXXForRangeStmt;
 }
 
