@@ -24,7 +24,7 @@ SignalWithReturnValue::SignalWithReturnValue(const std::string &name, ClazyConte
 
 void SignalWithReturnValue::VisitDecl(clang::Decl *decl)
 {
-    AccessSpecifierManager *accessSpecifierManager = m_context->accessSpecifierManager;
+    const AccessSpecifierManager *accessSpecifierManager = m_context->accessSpecifierManager;
     auto *method = dyn_cast<CXXMethodDecl>(decl);
     if (!accessSpecifierManager || !method) {
         return;
