@@ -11,13 +11,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Decl;
-class Stmt;
-} // namespace clang
-
 /**
  * See README-thread-with-slots.md for more info.
  */
