@@ -29,3 +29,9 @@ void qdatetimeutc()
 {
     QDateTime::currentDateTime().toSecsSinceEpoch();
 }
+
+void suppressionnextline()
+{   // clazy:exclude-next-line=qstring-allocations
+    QString s1 = "foo";
+    QString s2 = "foo";
+}
